@@ -566,7 +566,7 @@ echo "- Check backup logs in /var/log/whp-backup-*.log"
 echo "- Check WordPress auto-update logs in /var/log/wordpress-auto-update.log"
 echo "- WordPress management includes WP-CLI integration, security settings, auto-updates, and backup functionality"
 echo "- Check terminal server logs: journalctl -u whp-terminal -f"
-echo "- Verify WebSocket proxy is working: check /terminal-ws endpoint"
+echo "- Verify WebSocket proxy: curl -I http://localhost:8080/terminal-ws"
 echo "REBOOT THE SERVER NOW"
 echo ""
 
