@@ -14,13 +14,6 @@ if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
     exit;
 }
 
-$nonce = $_SERVER['HTTP_X_NONCE'] ?? '';
-if ($nonce !== $_SESSION['nonce']) {
-    $response['error'] = 'Invalid nonce';
-    echo json_encode($response);
-    exit;
-}
-
 $input = json_decode(file_get_contents('php://input'), true);
 $action = $input['action'] ?? '';
 
